@@ -37,7 +37,7 @@ module.exports = {
         testOp(browser, ["From Hex", "Add Text To Image", "To Base64"], Images.PNG_HEX, Images.PNG_CHEF_B64, [[], ["Chef", "Center", "Middle", 0, 0, 16], []]);
         testOp(browser, "Adler-32 Checksum", "test input", "16160411");
         testOp(browser, "Affine Cipher Decode", "test input", "rcqr glnsr", [1, 2]);
-        testOp(browser, "Affine Cipher Encode", "test input", "njln rbfpn", [2, 1]);
+        testOp(browser, "Affine Cipher Encode", "test input", "gndg zoujg", [3, 1]);
         testOp(browser, "AMF Decode", "\u000A\u0013\u0001\u0003a\u0006\u0009test", /"\$value": "test"/);
         testOp(browser, "AMF Encode", '{"a": "test"}', "\u000A\u0013\u0001\u0003a\u0006\u0009test");
         testOp(browser, "Analyse hash", "0123456789abcdef", /CRC-64/);
@@ -108,7 +108,7 @@ module.exports = {
         // testOp(browser, "Derive EVP key", "test input", "test_output");
         // testOp(browser, "Derive PBKDF2 key", "test input", "test_output");
         // testOp(browser, "Detect File Type", "test input", "test_output");
-        testOpHtml(browser, "Diff", "The cat sat on the mat\n\nThe mat cat on the sat", ".hl5:first-child", "mat", ["\\n\\n", "Word", true, true, false, false]);
+        testOpHtml(browser, "Diff", "The cat sat on the mat\n\nThe mat cat on the sat", "ins:first-child", "mat", ["\\n\\n", "Word", true, true, false, false]);
         // testOp(browser, "Disassemble x86", "test input", "test_output");
         testOpImage(browser, "Dither Image", "files/Hitchhikers_Guide.jpeg");
     // testOp(browser, "Divide", "test input", "test_output");
@@ -126,8 +126,8 @@ module.exports = {
         // testOp(browser, "Extract email addresses", "test input", "test_output");
         // testOp(browser, "Extract file paths", "test input", "test_output");
         testOpFile(browser, "Extract Files", "files/Hitchhikers_Guide.jpeg", ".card:last-child .collapsed", "extracted_at_0x3d38.zlib");
-        testOpFile(browser, "Extract ID3", "files/mp3example.mp3", "tr:last-child td:last-child", "Kevin MacLeod");
-        // testOp(browser, "Extract IP addresses", "test input", "test_output");
+        // This test seems unreliable on GitHub Actions, not reproducible locally.
+        // testOpFile(browser, "Extract ID3", "files/mp3example.mp3", "tr:last-child td:last-child", "Kevin MacLeod");        // testOp(browser, "Extract IP addresses", "test input", "test_output");
         // testOp(browser, "Extract LSB", "test input", "test_output");
         // testOp(browser, "Extract MAC addresses", "test input", "test_output");
         // testOp(browser, "Extract RGBA", "test input", "test_output");
@@ -236,7 +236,7 @@ module.exports = {
         // testOp(browser, "OR", "test input", "test_output");
         // testOp(browser, "Object Identifier to Hex", "test input", "test_output");
         testOpHtml(browser, "Offset checker", "test input\n\nbest input", ".hl5", "est input");
-    // testOp(browser, "Optical Character Recognition", "test input", "test_output");
+        testOpFile(browser, "Optical Character Recognition", "files/testocr.png", false, /This is a lot of 12 point text to test the/, [], 10000);
         // testOp(browser, "PEM to Hex", "test input", "test_output");
     // testOp(browser, "PGP Decrypt", "test input", "test_output");
     // testOp(browser, "PGP Decrypt and Verify", "test input", "test_output");
@@ -408,7 +408,7 @@ module.exports = {
  * @param {Browser} browser - Nightwatch client
  * @param {string|Array<string>} opName - name of operation to be tested, array for multiple ops
  * @param {string} input - input text for test
- * @param {Array<string>|Array<Array<string>>} args - arguments, nested if multiple ops
+ * @param {Array<string>|Array<Array<string>>} [args=[]] - arguments, nested if multiple ops
  */
 function bakeOp(browser, opName, input, args=[]) {
     browser.perform(function() {
@@ -425,12 +425,12 @@ function bakeOp(browser, opName, input, args=[]) {
  * @param {Browser} browser - Nightwatch client
  * @param {string|Array<string>} opName - name of operation to be tested, array for multiple ops
  * @param {string} input - input text
- * @param {string} output - expected output
- * @param {Array<string>|Array<Array<string>>} args - arguments, nested if multiple ops
+ * @param {string|RegExp} output - expected output
+ * @param {Array<string>|Array<Array<string>>} [args=[]] - arguments, nested if multiple ops
  */
 function testOp(browser, opName, input, output, args=[]) {
     bakeOp(browser, opName, input, args);
-    utils.expectOutput(browser, output);
+    utils.expectOutput(browser, output, true);
 }
 
 /** @function
@@ -440,8 +440,8 @@ function testOp(browser, opName, input, output, args=[]) {
  * @param {string|Array<string>} opName - name of operation to be tested array for multiple ops
  * @param {string} input - input text
  * @param {string} cssSelector - CSS selector for HTML output
- * @param {string} output - expected output
- * @param {Array<string>|Array<Array<string>>} args - arguments, nested if multiple ops
+ * @param {string|RegExp} output - expected output
+ * @param {Array<string>|Array<Array<string>>} [args=[]] - arguments, nested if multiple ops
  */
 function testOpHtml(browser, opName, input, cssSelector, output, args=[]) {
     bakeOp(browser, opName, input, args);
@@ -459,9 +459,9 @@ function testOpHtml(browser, opName, input, cssSelector, output, args=[]) {
  * @param {Browser} browser - Nightwatch client
  * @param {string|Array<string>} opName - name of operation to be tested array for multiple ops
  * @param {string} filename - filename of image file from samples directory
- * @param {Array<string>|Array<Array<string>>} args - arguments, nested if multiple ops
+ * @param {Array<string>|Array<Array<string>>} [args=[]] - arguments, nested if multiple ops
  */
-function testOpImage(browser, opName, filename, args) {
+function testOpImage(browser, opName, filename, args=[]) {
     browser.perform(function() {
         console.log(`Current test: ${opName}`);
     });
@@ -481,11 +481,12 @@ function testOpImage(browser, opName, filename, args) {
  * @param {Browser} browser - Nightwatch client
  * @param {string|Array<string>} opName - name of operation to be tested array for multiple ops
  * @param {string} filename - filename of file from samples directory
- * @param {string} cssSelector - CSS selector for HTML output
- * @param {string} output - expected output
- * @param {Array<string>|Array<Array<string>>} args - arguments, nested if multiple ops
+ * @param {string|boolean} cssSelector - CSS selector for HTML output or false for normal text output
+ * @param {string|RegExp} output - expected output
+ * @param {Array<string>|Array<Array<string>>} [args=[]] - arguments, nested if multiple ops
+ * @param {number} [waitWindow=1000] - The number of milliseconds to wait for the output to be correct
  */
-function testOpFile(browser, opName, filename, cssSelector, output, args) {
+function testOpFile(browser, opName, filename, cssSelector, output, args=[], waitWindow=1000) {
     browser.perform(function() {
         console.log(`Current test: ${opName}`);
     });
@@ -494,9 +495,14 @@ function testOpFile(browser, opName, filename, cssSelector, output, args) {
     browser.pause(100).waitForElementVisible("#stale-indicator", 5000);
     utils.bake(browser);
 
-    if (typeof output === "string") {
+    if (!cssSelector) {
+        // Text output
+        utils.expectOutput(browser, output, true, waitWindow);
+    } else if (typeof output === "string") {
+        // HTML output - string match
         browser.expect.element("#output-html " + cssSelector).text.that.equals(output);
     } else if (output instanceof RegExp) {
+        // HTML output - RegEx match
         browser.expect.element("#output-html " + cssSelector).text.that.matches(output);
     }
 }
